@@ -12,6 +12,16 @@ func TestCollect(t *testing.T) {
 	main.TestCollectImpl(t)
 }
 
+// TestCompile tests C.CompileInsights.
+func TestCompile(t *testing.T) {
+	main.TestCompileImpl(t)
+}
+
+// TestWrite tests C.WriteInsights.
+func TestWrite(t *testing.T) {
+	main.TestWriteImpl(t)
+}
+
 // TestUpload tests C.UploadInsights.
 func TestUpload(t *testing.T) {
 	main.TestUploadImpl(t)
